from .core import process

__all__ =\
[
	'appveyor',
	'azure',
	'bamboo',
	'bitbucket',
	'buddy',
	'circle',
	'codeship',
	'custom',
	'datadog',
	'github',
	'gitlab',
	'heroku',
	'jenkins',
	'netlify',
	'teamcity',
	'travis',
	'vercel'
]
